==> mapsforge_flutter-1.0.0.tar.gz: lib/src/implementation/graphics/fluttergraphicsfactory.dart <==
import 'dart:typed_data';
import 'dart:ui' as ui;

import 'package:flutter/material.dart';
import 'package:mapsforge_flutter/src/graphics/color.dart';
import 'package:mapsforge_flutter/src/graphics/display.dart';
import 'package:mapsforge_flutter/src/graphics/graphicfactory.dart';
import 'package:mapsforge_flutter/src/graphics/hillshadingbitmap.dart';
import 'package:mapsforge_flutter/src/graphics/mapcanvas.dart';
import 'package:mapsforge_flutter/src/graphics/mappaint.dart';
import 'package:mapsforge_flutter/src/graphics/mappath.dart';
import 'package:mapsforge_flutter/src/graphics/maprect.dart';
import 'package:mapsforge_flutter/src/graphics/matrix.dart';
import 'package:mapsforge_flutter/src/graphics/position.dart';
import 'package:mapsforge_flutter/src/graphics/resourcebitmap.dart';
import 'package:mapsforge_flutter/src/graphics/tilebitmap.dart';
import 'package:mapsforge_flutter/src/inputstream.dart';
import 'package:mapsforge_flutter/src/mapelements/pointtextcontainer.dart';
import 'package:mapsforge_flutter/src/mapelements/symbolcontainer.dart';
import 'package:mapsforge_flutter/src/model/boundingbox.dart';
import 'package:mapsforge_flutter/src/model/mappoint.dart';

import '../../graphics/bitmap.dart';
import 'fluttercanvas.dart';
import 'fluttercolor.dart';
import 'fluttermatrix.dart';
import 'flutterpaint.dart';
import 'flutterpath.dart';
import 'flutterpointtextcontainer.dart';
import 'flutterrect.dart';
import 'fluttertilebitmap.dart';

class FlutterGraphicFactory implements GraphicFactory {
  @override
  Bitmap createBitmap(int width, int height, bool isTransparent) {
    // TODO: implement createBitmap
    return null;
  }

  @override
  MapCanvas createCanvas(double width, double height) {
    return FlutterCanvas.forRecorder(width, height);
  }

  @override
  int createColor(Color color) {
    return FlutterColor.getColor(color);
  }

  @override
  int createColorSeparate(int alpha, int red, int green, int blue) {
    return alpha << 24 | red << 16 | green << 8 | blue;
  }

  @override
  Matrix createMatrix() {
    return FlutterMatrix();
  }

  @override
  HillshadingBitmap createMonoBitmap(int width, int height, Uint8List buffer, int padding, BoundingBox area) {
    // TODO: implement createMonoBitmap
    return null;
  }

  @override
  PointTextContainer createPointTextContainer(Mappoint xy, Display display, int priority, String text, MapPaint paintFront,
      MapPaint paintBack, SymbolContainer symbolContainer, Position position, int maxTextWidth) {
    return FlutterPointTextContainer(xy, display, priority, text, paintFront, paintBack, symbolContainer, position, maxTextWidth);
  }

  @override
  ResourceBitmap createResourceBitmap(InputStream inputStream, double scaleFactor, int width, int height, int percent) {
    // TODO: implement createResourceBitmap
    return null;
  }

  @override
  TileBitmap createTileBitmap(double tileSize, bool isTransparent, {InputStream inputStream}) {
    throw Exception("Cannot create a tileBitmap without bitmap");
    return FlutterTileBitmap(null);
  }

  @override
  InputStream platformSpecificSources(String relativePathPrefix, String src) {
    // TODO: implement platformSpecificSources
    return null;
  }

  @override
  ResourceBitmap renderSvg(InputStream inputStream, double scaleFactor, int width, int height, int percent) {
    // TODO: implement renderSvg
    return null;
  }

  @override
  MapPaint createPaint() {
    return FlutterPaint(ui.Paint());
  }

  @override
  MapPaint createPaintFrom(MapPaint from) {
    return FlutterPaint.from(from);
  }

  @override
  MapPath createPath() {
    return FlutterPath(ui.Path());
  }

  @override
  MapRect createRect(double left, double top, double right, double bottom) {
    return FlutterRect(left, top, right, bottom);
  }
}

==> mapsforge_flutter-1.1.0.tar.gz: lib/src/implementation/graphics/fluttergraphicsfactory.dart <==
import 'dart:typed_data';
import 'dart:ui' as ui;

import 'package:flutter/material.dart';
import 'package:mapsforge_flutter/src/cache/symbolcache.dart';
import 'package:mapsforge_flutter/src/graphics/color.dart';
import 'package:mapsforge_flutter/src/graphics/display.dart';
import 'package:mapsforge_flutter/src/graphics/graphicfactory.dart';
import 'package:mapsforge_flutter/src/graphics/hillshadingbitmap.dart';
import 'package:mapsforge_flutter/src/graphics/mapcanvas.dart';
import 'package:mapsforge_flutter/src/graphics/mappaint.dart';
import 'package:mapsforge_flutter/src/graphics/mappath.dart';
import 'package:mapsforge_flutter/src/graphics/maprect.dart';
import 'package:mapsforge_flutter/src/graphics/matrix.dart';
import 'package:mapsforge_flutter/src/graphics/position.dart';
import 'package:mapsforge_flutter/src/graphics/resourcebitmap.dart';
import 'package:mapsforge_flutter/src/graphics/tilebitmap.dart';
import 'package:mapsforge_flutter/src/inputstream.dart';
import 'package:mapsforge_flutter/src/mapelements/pointtextcontainer.dart';
import 'package:mapsforge_flutter/src/mapelements/symbolcontainer.dart';
import 'package:mapsforge_flutter/src/model/boundingbox.dart';
import 'package:mapsforge_flutter/src/model/mappoint.dart';

import '../../graphics/bitmap.dart';
import 'fluttercanvas.dart';
import 'fluttercolor.dart';
import 'fluttermatrix.dart';
import 'flutterpaint.dart';
import 'flutterpath.dart';
import 'flutterpointtextcontainer.dart';
import 'flutterrect.dart';
import 'fluttertilebitmap.dart';

class FlutterGraphicFactory extends GraphicFactory {
  FlutterGraphicFactory(SymbolCache symbolCache) : super(symbolCache);

  // @override
  // Bitmap createBitmap(int width, int height, bool isTransparent) {
  //   // TODO: implement createBitmap
  //   return null;
  // }

  @override
  MapCanvas createCanvas(double width, double height, [String src]) {
    return FlutterCanvas.forRecorder(width, height, src);
  }

  @override
  int createColor(Color color) {
    return FlutterColor.getColor(color);
  }

  @override
  int createColorSeparate(int alpha, int red, int green, int blue) {
    return alpha << 24 | red << 16 | green << 8 | blue;
  }

  @override
  Matrix createMatrix() {
    return FlutterMatrix();
  }

  // @override
  // HillshadingBitmap createMonoBitmap(int width, int height, Uint8List buffer, int padding, BoundingBox area) {
  //   // TODO: implement createMonoBitmap
  //   return null;
  // }

  @override
  PointTextContainer createPointTextContainer(Mappoint xy, Display display, int priority, String text, MapPaint paintFront,
      MapPaint paintBack, SymbolContainer symbolContainer, Position position, int maxTextWidth) {
    return FlutterPointTextContainer(xy, display, priority, text, paintFront, paintBack, symbolContainer, position, maxTextWidth);
  }

  // @override
  // ResourceBitmap createResourceBitmap(InputStream inputStream, double scaleFactor, int width, int height, int percent) {
  //   // TODO: implement createResourceBitmap
  //   return null;
  // }

  // @override
  // TileBitmap createTileBitmap(double tileSize, bool isTransparent, {InputStream inputStream}) {
  //   throw Exception("Cannot create a tileBitmap without bitmap");
  //   return FlutterTileBitmap(null);
  // }
  //
  // @override
  // InputStream platformSpecificSources(String relativePathPrefix, String src) {
  //   // TODO: implement platformSpecificSources
  //   return null;
  // }
  //
  // @override
  // ResourceBitmap renderSvg(InputStream inputStream, double scaleFactor, int width, int height, int percent) {
  //   // TODO: implement renderSvg
  //   return null;
  // }

  @override
  MapPaint createPaint() {
    return FlutterPaint(ui.Paint());
  }

  @override
  MapPaint createPaintFrom(MapPaint from) {
    return FlutterPaint.from(from);
  }

  @override
  MapPath createPath() {
    return FlutterPath(ui.Path());
  }

  @override
  MapRect createRect(double left, double top, double right, double bottom) {
    return FlutterRect(left, top, right, bottom);
  }
}
